package com.lbs.ws.test;

import java.rmi.RemoteException;

import org.apache.axis2.client.ServiceClient;
import org.apache.axis2.context.ConfigurationContext;
import org.apache.axis2.context.ConfigurationContextFactory;
import org.apache.rampart.handler.WSSHandlerConstants;
import org.apache.rampart.handler.config.OutflowConfiguration;

import com.lbs.ws.query.DataQueryServiceStub;
import com.lbs.ws.query.First;
import com.lbs.ws.query.FirstResponse;
import com.lbs.ws.query.GetBrowserQueryInfo;
import com.lbs.ws.query.GetBrowserQueryInfoResponse;
import com.lbs.ws.query.GetRowCount;
import com.lbs.ws.query.GetRowCountResponse;
import com.lbs.ws.query.Last;
import com.lbs.ws.query.LastResponse;
import com.lbs.ws.query.Previous;
import com.lbs.ws.query.PreviousResponse;
import com.lbs.ws.query.Search;
import com.lbs.ws.query.SearchResponse;
import com.lbs.ws.query.xsd.DataQueryBrowserFilter;
import com.lbs.ws.query.xsd.DataQueryBrowserInfo;
import com.lbs.ws.query.xsd.DataQueryCountResult;
import com.lbs.ws.query.xsd.DataQueryParams;
import com.lbs.ws.query.xsd.DataQueryResult;
import com.lbs.ws.query.xsd.DataQueryResultRow;

public class DataQueryServiceTest {

	
private static String m_RootURL = "http://localhost:8080/logo/services/";
    
    public static void main(java.lang.String args[])
    {
      try
		{
			ConfigurationContext cfg = ConfigurationContextFactory.createConfigurationContextFromFileSystem("D:\\osman",null);
			DataQueryServiceStub stub = new DataQueryServiceStub(cfg, m_RootURL + "DataQueryService" );
			ServiceClient sc = stub._getServiceClient();
			sc.engageModule("addressing");
			sc.engageModule("rampart");			
			
			OutflowConfiguration outflowConfig = new OutflowConfiguration();
			outflowConfig.setActionItems("UsernameToken");
			outflowConfig.setUser("admin");
			outflowConfig.setPasswordCallbackClass("com.lbs.ws.test.SampleCallBackHandler");
			sc.getOptions().setProperty(WSSHandlerConstants.OUTFLOW_SECURITY, outflowConfig.getProperty());
			
//			getItemBrowserQueryInfo(stub);
//			firstNRows(stub);
//			lastNRows(stub);
//			getRowCount(stub);
//			search(stub);
			previous(stub);
		}
		catch (RemoteException e)
		{
			e.printStackTrace();
		}
    }

	private static void previous(DataQueryServiceStub stub) 
	{
		try 
		{
			Previous methodParams = new Previous();
			methodParams.setMaxCount(4);
			methodParams.setQueryName("MMQOItemBrowser");
			methodParams.setRefPrimaryKey(7);
			DataQueryParams param = new DataQueryParams();
			param.setFirm(1);
			param.setPeriod(1);
			methodParams.setParams(param );
			PreviousResponse response = stub.previous(methodParams);
			DataQueryResult retVal = response.get_return();
			String errorMessage = retVal.getErrorMessage();
			DataQueryResultRow[] rows = retVal.getRows();
			boolean successful = retVal.getSuccessful();
			System.out.println(successful + "\n " + errorMessage);
		}
		catch (RemoteException e) 
		{
			e.printStackTrace();
		}
	}

	private static void search(DataQueryServiceStub stub) 
	{
		try 
		{
			Search methodParams = new Search();
			methodParams.setMaxCount(10);
			methodParams.setQueryName("MMQOItemBrowser");
			methodParams.setRefPrimaryKey(7);
			methodParams.setReverse(false);
			methodParams.setSearchComparison(3);
			DataQueryParams param = new DataQueryParams();
			param.setFirm(1);
			param.setPeriod(1);
			methodParams.setParams(param);
			
			SearchResponse search = stub.search(methodParams);
			DataQueryResult retVal = search.get_return();
			String errorMessage = retVal.getErrorMessage();
			System.out.println(errorMessage);
			DataQueryResultRow[] rows = retVal.getRows();
			boolean successful = retVal.getSuccessful();
			System.out.println(successful);
		} 
		catch (RemoteException e)
		{
			e.printStackTrace();
		}
	}

	private static void getRowCount(DataQueryServiceStub stub) 
	{
		try 
		{
			GetRowCount methodParams = new GetRowCount();
			methodParams.setQueryName("MMQOItemBrowser");
			DataQueryParams dataParams = new DataQueryParams();
			dataParams.setFirm(1);
			dataParams.setPeriod(1);
			methodParams.setParams(dataParams );
			GetRowCountResponse response = stub.getRowCount(methodParams);
			DataQueryCountResult retVal = response.get_return();
			int rowCount = retVal.getRowCount();
			System.out.println("Count :" + rowCount + " Succesful : "  + retVal.getSuccessful());
			
		}
		catch (RemoteException e) 
		{
			e.printStackTrace();
		}
	}

	private static void lastNRows(DataQueryServiceStub stub) 
	{
		try
		{
			Last methodParams = new Last();
			methodParams.setMaxCount(5);
			methodParams.setQueryName("MMQOItemBrowser");
			methodParams.setReverse(false);
			DataQueryParams dataParams = new DataQueryParams();
			dataParams.setFirm(1);
			dataParams.setPeriod(1);
			methodParams.setParams(dataParams);
			LastResponse last = stub.last(methodParams );
			DataQueryResultRow[] rows = last.get_return().getRows();
			boolean successful = last.get_return().getSuccessful();
			System.out.println(successful + " " + last.get_return().getErrorMessage());
		}
		catch (Exception e) 
		{
			e.printStackTrace();
		}
	}

	private static void firstNRows(DataQueryServiceStub stub)  
	{
		try {
			First methodParams = new First();
			methodParams.setMaxCount(3);
			methodParams.setQueryName("MMQOItemBrowser");
			methodParams.setReverse(false);
			DataQueryParams dataParams = new DataQueryParams();
			methodParams.setParams(dataParams );
			dataParams.setFirm(1);
			dataParams.setPeriod(1);
			FirstResponse first = stub.first(methodParams);
			DataQueryResult retVal = first.get_return();
			String errorMessage = retVal.getErrorMessage();
			DataQueryResultRow[] rows = retVal.getRows();
			System.out.println(retVal.getSuccessful());
			System.out.println(errorMessage);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
		
	}

	private static void getItemBrowserQueryInfo(DataQueryServiceStub stub) 
	{
		try 
		{
			GetBrowserQueryInfo methodParams = new GetBrowserQueryInfo();
			methodParams.setBrowserName("MMXFItemBrowser");
			methodParams.setLanguage("TRTR");
			methodParams.setFirm(1);
			methodParams.setPeriod(1);
			GetBrowserQueryInfoResponse info = stub.getBrowserQueryInfo(methodParams);
			DataQueryBrowserInfo retVal = info.get_return();
			String errorMessage = retVal.getErrorMessage();
			boolean successful = retVal.getSuccessful();
			String queryName = retVal.getQueryName();
			DataQueryBrowserFilter[] filters = retVal.getFilters();
			System.err.println();
			System.err.println("Succes: " + successful + " Error Msg: " + errorMessage + " queryname: " + queryName);
			
		} 
		catch (RemoteException e) 
		{
			e.printStackTrace();
		}
	}

}
